Learn R Programming

ggfoundry (version 0.3.1)

shapes_cast: Get the names of available shapes

Description

[Experimental]

Create a data frame of available shapes and associated sets. This may be filtered and used as a vector of strings in scale_shape_manual().

Usage

shapes_cast()

Arguments

Value

A data frame of available sets and shapes.

Examples

Run this code
# Returns a data frame of available shapes
shapes_cast()

Run the code above in your browser using DataLab