powered by
Create a data frame of available shapes and associated sets. This may be filtered and used as a vector of strings in scale_shape_manual().
scale_shape_manual()
shapes_cast()
A data frame of available sets and shapes.
# Returns a data frame of available shapes shapes_cast()
Run the code above in your browser using DataLab